calc_mean: Calculate the mean response for a yada mean specification

Description Usage Arguments Value

View source: R/mean_calculations.R

Description

Calculate the mean, f, given x, the parameter vector a, and the mean specification mean_spec.

Usage

1
calc_mean(x, mean_spec, a = NA)

Arguments

x

The independent variable

mean_spec

The mean specification

a

The parameter vector

Value

f(x,a), the mean (same length as x)


MichaelHoltonPrice/yada documentation built on Sept. 19, 2021, 11:27 p.m.