fail_for_beta2: A helper function to check whether the fits in TH_y fail for...

Description Usage Arguments

View source: R/cross_validation.R

Description

A helper function to check whether the fits in TH_y fail for beta2

Usage

1
fail_for_beta2(TH_y, beta2_max)

Arguments

TH_y

TH_y is a matrix with dimensions num_param x (1+num_folds)

beta2_max

beta2 threshold


MichaelHoltonPrice/yada documentation built on Sept. 19, 2021, 11:27 p.m.