get_num_var_mean: Get the number of variables for a yada mean specification

Description Usage Arguments Value

View source: R/mean_calculations.R

Description

Return the number of parameters for the mean specification mean_spec.

Usage

1
get_num_var_mean(mean_spec)

Arguments

mean_spec

The mean specification

Value

The number of mean parameters


MichaelHoltonPrice/yada documentation built on Sept. 19, 2021, 11:27 p.m.