get_var_index_multivariate_fast: Quickly get the indices in the parameter vector th_y of named...

Description Usage Arguments Value

View source: R/multivariate_models.R

Description

Accomplishes the same task as [get_var_index_multivariate], but using a pre-built mapping to increase the speed of the lookup.

Usage

1
2
3
4
5
6
7
8
9
get_var_index_multivariate_fast(
  var_name,
  mapping,
  j = NA,
  k = NA,
  i = NA,
  i1 = NA,
  i2 = NA
)

Arguments

var_name

The variable name (a, tau, alpha, z)

j

The ordinal index

k

The continuous index

i

The overall index

i1

The overall index for the first variable of a pair

i2

The overall index for the second variable of a pair

Value

The indices in the full parameter vector, th_y


MichaelHoltonPrice/yada documentation built on Sept. 19, 2021, 11:27 p.m.