get_var_index_univariate_cont: Get the variable indices for a univariate, continuous model...

Description Usage Arguments Value

View source: R/univariate_models.R

Description

Get the variable indices for a univariate, continuous model given the variable name (either c or kappa)

Usage

1
get_var_index_univariate_cont(var_name, mod_spec)

Arguments

var_name

The variable name (either c or kappa)

mod_spec

The model specification

Value

The variable indices


MichaelHoltonPrice/yada documentation built on Sept. 19, 2021, 11:27 p.m.