get_var_index_univariate_ord: Get the variable indices for a univariate, ordinal model...

Description Usage Arguments Value

View source: R/univariate_models.R

Description

Get the variable indices for a univariate, ordinal model given the variable name (b, tau, or beta)

Usage

1
get_var_index_univariate_ord(var_name, mod_spec)

Arguments

var_name

The variable name (b, tau, or beta)

mod_spec

The model specification

Value

The variable indices


MichaelHoltonPrice/yada documentation built on Sept. 19, 2021, 11:27 p.m.