Description Usage Arguments Value
The data directory (data_dir) contains a main problem file uniquely determined by the analysis name (analysis_name), and possibly some corresponding fold problems. Return a list of univariate problems to solve. The model specifications to include in the returned list are specified by mean_specs and noise_specs, which must be the same lengths. By default, all combinations of mean specifications and noise specifications supported by yada are used; there are three ordinal mean specifications (pow_law_ord, log_ord, and lin_ord) and two noise specifications (const and lin_pos_int), so by default there are num_models = 6 six total model specifications. By default, cross validation fold problems are not included, in which case the return list, ord_prob_list, has length num_models * J. If the cross validation problems are included, ord_prob_list has length num_models * J * (1+num_folds).
1 2 3 4 5 6 7 |
data_dir |
The data directory with problems and results |
analysis_name |
A unique analysis name (for the input data directory) |
mean_specs |
A vector of mean specifications for the ordinal models (default: [c('pow_law_ord','pow_law_ord','log_ord','log_ord','lin_ord','lin_ord']) |
noise_specs |
A vector of noise specifications for the ordinal models (default: [c('const','lin_pos_int','const','lin_pos_int','const','lin_pos_int']) |
add_folds |
Whether or not to include cross validation folds in the return list |
A list of problems
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.