Description Usage Arguments Value
View source: R/multivariate_models.R
Accomplishes the same task as [get_var_index_multivariate], but using a pre-built mapping to increase the speed of the lookup.
1 2 3 4 5 6 7 8 9 |
var_name |
The variable name (a, tau, alpha, z) |
j |
The ordinal index |
k |
The continuous index |
i |
The overall index |
i1 |
The overall index for the first variable of a pair |
i2 |
The overall index for the second variable of a pair |
The indices in the full parameter vector, th_y
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.